<?php
declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\TestFixture;

use PHPUnit\Framework\Attributes\RequiresEnvironmentVariable;
use PHPUnit\Framework\TestCase;

final class RequirementsEnvironmentVariableTest extends TestCase
{
    #[RequiresEnvironmentVariable('FOO', 'bar')]
    #[RequiresEnvironmentVariable('BAR')]
    #[RequiresEnvironmentVariable('BAZ')]
    public function testRequiresEnvironmentVariable(): void
    {
    }
}
