<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\TextUI\Configuration;

/**
 * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
 *
 * @immutable
 */
final readonly class FilterDirectory
{
    /**
     * @var non-empty-string
     */
    private string $path;
    private string $prefix;
    private string $suffix;
    private bool $includeInCodeCoverage;

    /**
     * @param non-empty-string $path
     */
    public function __construct(string $path, string $prefix, string $suffix, bool $includeInCodeCoverage = true)
    {
        $this->path                  = $path;
        $this->prefix                = $prefix;
        $this->suffix                = $suffix;
        $this->includeInCodeCoverage = $includeInCodeCoverage;
    }

    /**
     * @return non-empty-string
     */
    public function path(): string
    {
        return $this->path;
    }

    public function prefix(): string
    {
        return $this->prefix;
    }

    public function suffix(): string
    {
        return $this->suffix;
    }

    public function includeInCodeCoverage(): bool
    {
        return $this->includeInCodeCoverage;
    }
}
