<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
use PHPUnit\Framework\TestCase;

interface I
{
    public function m(): string;
}

final class Issue6362Test extends TestCase
{
    public function testOne(): void
    {
        $this->assertSame('', (new ($this->createStub(I::class)::class))->m());
    }
}
