<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\TestFixture\Event;

use PHPUnit\Framework\Attributes\DataProvider;
use PHPUnit\Framework\TestCase;

final class DataProviderInParentTest extends ParentTestCase
{
}

abstract class ParentTestCase extends TestCase
{
    public static function data_provider(): iterable
    {
        yield [true];
    }

    #[DataProvider('data_provider')]
    public function testSomething(bool $var): void
    {
        $this->assertTrue($var);
    }
}
