<?php
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\TestFixture\ErrorHandler\PhpDeprecation;

use function strlen;

final class FirstPartyClass
{
    public function method(): true
    {
        @strlen(null);

        return true;
    }
}
